@@ -7,7 +7,7 @@ use Catalyst::Log;
 
 __PACKAGE__->mk_classdata($_) for qw/_config log/;
 
-our $VERSION = '4.23';
+our $VERSION = '4.24';
 our @ISA;
 
 =head1 NAME
@@ -32,9 +32,6 @@ Catalyst - The Elegant MVC Web Application Framework
     script/test.pl /yada
 
 
-    See also L<Catalyst::Manual::Intro>
-
-
     use Catalyst;
 
     use Catalyst qw/My::Module My::OtherModule/;
@@ -61,6 +58,8 @@ Catalyst - The Elegant MVC Web Application Framework
         }
     );
 
+See also L<Catalyst::Manual::Intro>
+
 =head1 DESCRIPTION
 
 Catalyst is based upon L<Maypole>, which you should consider for smaller
@@ -198,8 +197,9 @@ Sebastian Riedel, C<sri@oook.de>
 
 =head1 THANK YOU
 
-Danijel Milicevic, David Naughton, Gary Ashton Jones, Jesse Sheidlower,
-Johan Lindstrom, Marcus Ramberg and all the others who've helped.
+Andrew Ruthven, Danijel Milicevic, David Naughton, Gary Ashton Jones,
+Jesse Sheidlower, Johan Lindstrom, Marcus Ramberg and all the others
+who've helped.
 
 =head1 LICENSE
 
